'use client';
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var FigureImage = require('react-bootstrap/FigureImage');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);
var FigureImage__default = /*#__PURE__*/_interopDefault(FigureImage);

const Image = (props) => {
    const { file, className } = props;
    const { properties, cropVariants, publicUrl } = file;
    const { link, linkData } = properties;
    const crops = Object.keys(properties.crop);
    const sources = crops.map((cropIdentifier, index) => {
        let src;
        let media;
        switch (cropIdentifier) {
            case 'extrasmall':
                media = '(max-width: 575px)';
                src = cropVariants ? cropVariants.extrasmall.publicUrl : publicUrl;
                break;
            case 'small':
                media = '(min-width: 576px)';
                src = cropVariants ? cropVariants.small.publicUrl : publicUrl;
                break;
            case 'medium':
                media = '(min-width: 768px)';
                src = cropVariants ? cropVariants.medium.publicUrl : publicUrl;
                break;
            case 'large':
                media = '(min-width: 992px)';
                src = cropVariants ? cropVariants.large.publicUrl : publicUrl;
                break;
            default:
                media = '(min-width: 1200px)';
                src = cropVariants ? cropVariants.default.publicUrl : publicUrl;
                break;
        }
        return React__default.default.createElement("source", { key: index, srcSet: src, media: media });
    });
    let cssClasses = 'img-fluid';
    if (className) {
        cssClasses += ' ' + className;
    }
    let imageContent = React__default.default.createElement("picture", null,
        sources,
        React__default.default.createElement(FigureImage__default.default, { loading: "lazy", className: cssClasses, src: publicUrl, title: properties.title?.replace(/&quot;/gi, '"'), alt: properties.alternative }));
    if ((link !== null && link.length > 0) || (linkData !== undefined && linkData !== null)) {
        let linkProperties = {
            className: '',
            href: link,
            target: null,
            title: null
        };
        if (linkData !== undefined && linkData !== null) {
            linkProperties = {
                ...linkProperties,
                className: linkData['class'],
                href: linkData.href,
                target: linkData.target,
                title: linkData.title?.replace(/&quot;/gi, '"'),
                ...linkData.additionalAttributes
            };
        }
        imageContent = React__default.default.createElement("a", { ...linkProperties }, imageContent);
    }
    return imageContent;
};

exports.Image = Image;
exports.default = Image;
//# sourceMappingURL=Image.js.map
