import React from 'react';
import Link from '../../Partials/ContentElements/Link.js';
import AllHeader from '../../Partials/ContentElements/Header/All.js';

const CardGroup = (props) => {
    const { items } = props.data.content;
    const flexform = props.data.flexform;
    const cards = items.map((cardData, index_number) => {
        const { header, subheader, bodytext, image, link, linkTitle, linkClass } = cardData;
        const imageTemplate = image ? image.map((imageData, index) => React.createElement("img", { key: `image-data-${index}`, className: "card-image-top", src: imageData.publicUrl, alt: '' })) : React.createElement(React.Fragment, null);
        let linkButton = React.createElement(React.Fragment, null);
        if (link) {
            if (linkTitle && linkTitle.length > 0) {
                link.title = linkTitle;
            }
            if (linkClass && linkClass.length > 0) {
                link["class"] = `${link["class"]} btn-${linkClass}`;
            }
            linkButton = React.createElement(Link, { href: link.href, title: link.title, className: link['class'], target: link.target, linkText: link.linkText });
        }
        return React.createElement("div", { key: `col card-group-col-${index_number}` },
            React.createElement("div", { className: 'card' },
                header.length > 0 && React.createElement("div", { className: 'card-header' }, header),
                imageTemplate,
                React.createElement("div", { className: 'card-body' },
                    subheader.length > 0 && React.createElement("div", { className: 'card-title' }, subheader),
                    bodytext.length > 0 && React.createElement("div", { className: 'card-text' },
                        React.createElement("div", { dangerouslySetInnerHTML: { __html: bodytext } })),
                    linkButton)));
    });
    let alignment = 'justify-content-left';
    if (flexform.align.length > 0) {
        alignment = `justify-content-${flexform.align}`;
    }
    return React.createElement(React.Fragment, null,
        React.createElement(AllHeader, { data: props.data }),
        React.createElement("div", { className: `row row-xs-1 row-md-${flexform.columns} card-group ${alignment}` }, cards),
        props.children);
};

export { CardGroup as default };
//# sourceMappingURL=CardGroup.js.map
